.. currentmodule:: cratermaker

Projectile
==========

The Projectile component contains information about the populations of projectiles that are used when scaling between crater and projectile sizes.